powered by
Facilitate reporting for regression and correlation modeling, hypothesis testing, variance analysis, outlier detection, and detailed descriptive statistics.
Maintainer: Etienne Camenen etienne.camenen@gmail.com
Useful links:
https://github.com/ecamenen/GimmeMyStats
https://ecamenen.github.io/GimmeMyStats/
Report bugs at https://github.com/ecamenen/GimmeMyStats/issues