Learn R Programming

GimmeMyStats (version 1.0.0)

housetasks: Household tasks distribution by gender and arrangement

Description

A dataset containing the distribution of household tasks among different arrangements: Wife, Alternating, Husband, and Jointly. The data represents the frequency of each task performed by each arrangement.

Usage

data(housetasks)

Arguments

Format

A data.frame with 13 rows (tasks) and 4 columns (arrangements):

Wife

Numeric, the frequency of the task performed primarily by the wife.

Alternating

Numeric, the frequency of the task performed in an alternating manner.

Husband

Numeric, the frequency of the task performed primarily by the husband.

Jointly

Numeric, the frequency of the task performed jointly by both partners.

Examples

Run this code
data(housetasks)
head(housetasks)

Run the code above in your browser using DataLab