A character string containing a measure of central tendency and
dispersion. Depending on method, this is either the median and
interquartile range or the mean and standard deviation.
Arguments
x
Vector containing numerical values.
digits
Integer specifying the number of decimal places for the test
statistic.
width
Integer specifying the maximum width for wrapping text.
method
Character specifying the method: median for median and IQR, or mean for mean and SD.